pub struct CreditRegistrationErrorCodeWindow {
pub error_code: CreditRegistrationErrorCode,
pub retryability: Retryability,
pub current_count: i64,
pub previous_count: i64,
pub user_count: i64,
pub course_count: i64,
pub first_seen_at: Option<DateTime<Utc>>,
pub last_seen_at: Option<DateTime<Utc>>,
pub endpoints: Vec<SuotarEndpoint>,
}Expand description
One error code over the chosen window and the one before it.
Fields
error_code: CreditRegistrationErrorCoderetryability: RetryabilityWhat may be done about the code, which is the difference between a wait and a fix.
current_count: i64previous_count: i64user_count: i64course_count: i64first_seen_at: Option<DateTime<Utc>>last_seen_at: Option<DateTime<Utc>>endpoints: Vec<SuotarEndpoint>Trait Implementations
Sourceimpl Clone for CreditRegistrationErrorCodeWindow
impl Clone for CreditRegistrationErrorCodeWindow
Sourcefn clone(&self) -> CreditRegistrationErrorCodeWindow
fn clone(&self) -> CreditRegistrationErrorCodeWindow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for CreditRegistrationErrorCodeWindow
impl ComposeSchema for CreditRegistrationErrorCodeWindow
Sourceimpl<'de> Deserialize<'de> for CreditRegistrationErrorCodeWindow
impl<'de> Deserialize<'de> for CreditRegistrationErrorCodeWindow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreditRegistrationErrorCodeWindow
impl PartialEq for CreditRegistrationErrorCodeWindow
Sourcefn eq(&self, other: &CreditRegistrationErrorCodeWindow) -> bool
fn eq(&self, other: &CreditRegistrationErrorCodeWindow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl ToSchema for CreditRegistrationErrorCodeWindow
impl ToSchema for CreditRegistrationErrorCodeWindow
impl StructuralPartialEq for CreditRegistrationErrorCodeWindow