pub struct CreditRegistrationTerminalVerdicts {
pub registered_count: i64,
pub duplicate_and_not_improved_count: i64,
pub failed_permanent_count: i64,
pub cancelled_count: i64,
pub total_count: i64,
}Expand description
The verdicts an operator needs beside the errors to rule them out. not_improved is not a
failure and is never in the error table above.
Fields
registered_count: i64duplicate_and_not_improved_count: i64failed_permanent_count: i64cancelled_count: i64total_count: i64The denominator of the success rate.